Package: scDotPlot
Title: Cluster a Single-cell RNA-seq Dot Plot
Version: 1.3.1
Authors@R: c(
    person(given = c("Benjamin", "I"),
           family = "Laufer",
           role = c("aut", "cre"),
           email = "blaufer@gmail.com"),
    person(given = c("Brad", "A"),
           family = "Friedman",
           role = c("aut")))
Description: Dot plots of single-cell RNA-seq data allow for an examination of the relationships between cell groupings (e.g. clusters) and marker gene expression. The scDotPlot package offers a unified approach to perform a hierarchical clustering analysis and add annotations to the columns and/or rows of a scRNA-seq dot plot. It works with SingleCellExperiment and Seurat objects as well as data frames.
License: Artistic-2.0
URL: https://github.com/ben-laufer/scDotPlot
BugReports: https://github.com/ben-laufer/scDotPlot/issues
biocViews: Software, Visualization, DifferentialExpression,
        GeneExpression, Transcription, RNASeq, SingleCell, Sequencing,
        Clustering
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Depends: R (>= 4.4.0)
Imports: aplot, BiocGenerics, cli, dplyr, ggplot2, ggsci, ggtree,
        grDevices, magrittr, purrr, rlang, scales, scater, Seurat,
        SingleCellExperiment, stats, stringr, tibble, tidyr
Suggests: AnnotationDbi, BiocStyle, knitr, rmarkdown, scran, scRNAseq,
        scuttle, SeuratObject, testthat, vdiffr
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/scDotPlot
git_branch: devel
git_last_commit: 4db1f01
git_last_commit_date: 2025-07-10
Repository: Bioconductor 3.22
Date/Publication: 2025-10-07
NeedsCompilation: no
Packaged: 2025-10-07 23:56:39 UTC; biocbuild
Author: Benjamin I Laufer [aut, cre],
  Brad A Friedman [aut]
Maintainer: Benjamin I Laufer <blaufer@gmail.com>
