#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(".", "Average", "Feature", "Group", "NumDetected",
                         "avg.exp.scaled", "data", "features.plot",
                         "id", "pct.exp", ":="))

## usethis namespace: start
#' @importFrom magrittr %>% %$%
## usethis namespace: end
NULL
